# My ETH Predictor

This package helps predict Ethereum prices using an LSTM model and various technical indicators like RSI, EMA, MACD, and Bollinger Bands. This is LUCY or limiting uncertainty, control yourself.

Here is the API token for pypi: 
pypi-AgEIcHlwaS5vcmcCJDY1ZDEzMzAyLWIxODgtNGU4OS1hZmMyLWI4YmViY2U1MGM5ZAACKlszLCJjNTI4NWUyNS0zYjU0LTQzY2UtYTFkYy0xM2E3MzY1NzBiNjgiXQAABiBaqFZGUoczJ-JZuLhQaiU-zd12hk3ahhqleqdrYt2s8A

twine upload dist/* -u __token__ -p pypi-AgEIcHlwaS5vcmcCJDY1ZDEzMzAyLWIxODgtNGU4OS1hZmMyLWI4YmViY2U1MGM5ZAACKlszLCJjNTI4NWUyNS0zYjU0LTQzY2UtYTFkYy0xM2E3MzY1NzBiNjgiXQAABiBaqFZGUoczJ-JZuLhQaiU-zd12hk3ahhqleqdrYt2s8A

## Installation

